#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oedepict
from openeye import oegrapheme
from openeye import oeshape

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE GRAPHEME DOCUMENTATION
###############################################################

# @ <SNIPPET-DRAW-COLOR-FORCE-FIELD-LEGEND>
cff = oeshape.OEColorForceField()
cff.Init(oeshape.OEColorFFType_ImplicitMillsDean)
cffdisp = oegrapheme.OEColorForceFieldDisplay(cff)

rows, cols = 2, 3
opts = oegrapheme.OEColorForceFieldLegendDisplayOptions(rows, cols)

image = oedepict.OEImage(450, 150)
oegrapheme.OEDrawColorForceFieldLegend(image, cffdisp, opts)
# @ </SNIPPET-DRAW-COLOR-FORCE-FIELD-LEGEND>
oedepict.OEWriteImage("DrawColorForceFieldLegend.png", image)
oedepict.OEWriteImage("DrawColorForceFieldLegend.pdf", image)
