
# CONFIDENTIAL. (C) 2017 OpenEye Scientific Software Inc.
# All rights reserved.
#
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO OPENEYE
# SCIENTIFIC SOFTWARE INC., AND IS SUBJECT TO THE FULL PROTECTION OF
# COPYRIGHT AND TRADESECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from OpenEye is strictly
# prohibited and illegal. De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact OpenEye at eyesopen.com/legal if you have any questions
# about this warning.
"""
 Test suite for Lexichem TK examples
"""

import pytest
from . import OETestCase, check_license


@pytest.mark.skipif(check_license('lexichem') is False,
                    reason='Lexichem license not found')
class TestLexichem(OETestCase):

    def test_mol2nam(self):
        script = self.run_example('{0}/iupac/mol2nam_example.py'.format(self.EXAMPLES_DIR),
                                  '-i', '{0}/data.smi'.format(self.DATA_DIR))
        self.assertFalse(script.returncode)
