#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeszybki

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE SZYBKI DOCUMENTATION
###############################################################


def main(argv=sys.argv):
    if len(argv) != 2:
        oechem.OEThrow.Usage("%s <infile>" % argv[0])

    ifs = oechem.oemolistream()
    if not ifs.open(argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % argv[1])

    mol = oechem.OEMol()
    oechem.OEReadMolecule(ifs, mol)

    # @ <SNIPPET-OETORSIONSCAN>
    outmol = oechem.OEMol()

    opts = oeszybki.OETorsionScanOptions()
    opts.SetDelta(30.0)
    opts.SetForceFieldType(oeszybki.OEForceFieldType_MMFF94)
    opts.SetSolvationType(oeszybki.OESolventModel_NoSolv)

    for tor in oechem.OEGetTorsions(mol):
        print("Torsion: %d %d %d %d" %
              (tor.a.GetIdx(), tor.b.GetIdx(), tor.c.GetIdx(), tor.d.GetIdx()))
        for res in oeszybki.OETorsionScan(outmol, mol, tor, opts):
            print("%.2f %.2f" % (res.GetAngle(), res.GetEnergy()))
    # @ </SNIPPET-OETORSIONSCAN>


if __name__ == "__main__":
    sys.exit(main(sys.argv))
